@@ -5,10 +5,14 @@ import pkgutil
 def get_resource(filename):
     return pkgutil.get_data(__package__, 'data/' + filename)
 
+version = '0.3.5'
+
 categories = json.loads(get_resource('categories.json').decode())
 sorts = json.loads(get_resource('sorts.json').decode())
 blacklist = set(json.loads(get_resource('blacklist.json').decode()))
 
 default_headers = {'User-Agent': 'pirate get'}
 default_timeout = 10
-colored_output = True
+
+default_mirror = 'https://thepiratebay.org/'
+mirror_list = 'https://proxybay.bz/list.txt'
